@@ -450,6 +450,7 @@ mpv_handle *MpvProxy::mpv_init()
     my_set_property(pHandle, "panscan", 1.0);
     qDebug() << "DEBUG: panscan set to 1.0.";
 
+    qInfo() << "DecodeMode:" << m_decodeMode << "(AUTO:0, HARDWARE:1, SOFTWARE:2, CUSTOM:3)";
     if (DecodeMode::SOFTWARE == m_decodeMode) { //1.设置软解
         qDebug() << "DEBUG: Decode mode set to SOFTWARE. Setting hwdec to no.";
         my_set_property(pHandle, "hwdec", "no");
@@ -619,7 +620,7 @@ mpv_handle *MpvProxy::mpv_init()
 #endif
         if (utils::check_wayland_env()) {
             qInfo() << "V25 set ao auto";
-            my_set_property(pHandle, "ao", "auto");
+            my_set_property(pHandle, "ao", "sdl");
         }
 
         if (QFile::exists("/sys/bus/pci/drivers/ljmcore")) {
@@ -781,6 +782,7 @@ mpv_handle *MpvProxy::mpv_init()
     my_set_property(pHandle, "sub-border-size", 0);
     my_set_property(pHandle, "screenshot-template", "deepin-movie-shot%n");
     my_set_property(pHandle, "screenshot-directory", "/tmp");
+    my_set_property(pHandle, "stop-screensaver", "no"); // 屏幕保护逻辑影院自己控制，不由mpv控制
     qDebug() << "DEBUG: Basic MPV properties set.";
 
 #ifndef _LIBDMR_
@@ -1200,24 +1202,38 @@ void MpvProxy::processPropertyChange(mpv_event_property *pEvent)
     QString sName = QString::fromUtf8(pEvent->name);
     if (sName != "time-pos") qInfo() << sName;
 
-    if (sName == "time-pos") {
+    // 使用 QPointer 检查对象是否还存在
+    QPointer<MpvProxy> self(this);
+    QTimer::singleShot(0, [this, sName, self]() {
+        if (self.isNull()) {
+            qWarning() << "MpvProxy obj is destroyed";
+            return; // 对象已被销毁
+        }
+
+        processPropertyChange(sName);
+    });
+}
+
+void MpvProxy::processPropertyChange(const QString &name)
+{
+    if (name == "time-pos") {
         emit elapsedChanged();
-    } else if (sName == "volume") {
+    } else if (name == "volume") {
         emit volumeChanged();
-    } else if (sName == "dwidth" || sName == "dheight") {
+    } else if (name == "dwidth" || name == "dheight") {
         auto sz = videoSize();
         if (!sz.isEmpty())
             emit videoSizeChanged();
         qInfo() << "update videoSize " << sz;
-    } else if (sName == "aid") {
+    } else if (name == "aid") {
         emit aidChanged();
-    } else if (sName == "sid") {
+    } else if (name == "sid") {
         emit sidChanged();
-    } else if (sName == "mute") {
+    } else if (name == "mute") {
         emit muteChanged();
-    } else if (sName == "sub-visibility") {
+    } else if (name == "sub-visibility") {
         //_hideSub = my_get_property(m_handle, "sub-visibility")
-    } else if (sName == "pause") {
+    } else if (name == "pause") {
         auto idle = my_get_property(m_handle, "idle-active").toBool();
         if (my_get_property(m_handle, "pause").toBool()) {
             if (!idle)
@@ -1229,8 +1245,8 @@ void MpvProxy::processPropertyChange(mpv_event_property *pEvent)
                 setState(PlayState::Playing);
             }
         }
-    } else if (sName == "core-idle") {
-    } else if (sName == "paused-for-cache") {
+    } else if (name == "core-idle") {
+    } else if (name == "paused-for-cache") {
         qInfo() << "paused-for-cache" << my_get_property_variant(m_handle, "paused-for-cache");
         emit urlpause(my_get_property_variant(m_handle, "paused-for-cache").toBool());
     }
@@ -1487,6 +1503,7 @@ void MpvProxy::refreshDecode()
     QList<QString> canHwTypes;
     //bool bIsCanHwDec = HwdecProbe::get().isFileCanHwdec(_file.url(), canHwTypes);
 
+    qInfo() << "DecodeMode:" << m_decodeMode << "(AUTO:0, HARDWARE:1, SOFTWARE:2, CUSTOM:3)";
     if (DecodeMode::SOFTWARE == m_decodeMode) { //1.设置软解
         my_set_property(m_handle, "hwdec", "no");
     } else if (DecodeMode::AUTO == m_decodeMode) {//2.设置自动
@@ -1496,6 +1513,7 @@ void MpvProxy::refreshDecode()
             PlayItemInfo currentInfo = dynamic_cast<PlayerEngine *>(m_pParentWidget)->getplaylist()->currentInfo();
             auto codec = currentInfo.mi.videoCodec();
             auto name = _file.fileName();
+            qInfo() << "Codec:" << codec << "Name:" << name;
             isSoftCodec = codec.toLower().contains("mpeg2video") || codec.toLower().contains("wmv") || name.toLower().contains("wmv");
             //去除9200显卡适配
             QFileInfo jmfi("/dev/jmgpu");
@@ -1827,6 +1845,7 @@ void MpvProxy::play()
     QMap<QString, QString>::iterator iter = m_pConfig->begin();
     qInfo() << __func__ << "Set mpv propertys!!";
     while (iter != m_pConfig->end()) {
+        qInfo() << __func__ << iter.key() << iter.value();
         my_set_property(m_handle, iter.key(), iter.value());
         iter++;
     }
